==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/internal/knative/pkg/apis/duck/v1/WithPodSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WithPodSpecFluentImpl<A extends WithPodSpecFluent<A>> extends BaseFluent<A> implements WithPodSpecFluent<A>{
  public WithPodSpecFluentImpl() {
  }
  public WithPodSpecFluentImpl(WithPodSpec instance) {
    this.withTemplate(instance.getTemplate()); 
  }
  private PodSpecableBuilder template;
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSpecable getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public PodSpecable buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(PodSpecable template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new PodSpecableBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public WithPodSpecFluent.TemplateNested<A> withNewTemplate() {
    return new WithPodSpecFluentImpl.TemplateNestedImpl();
  }
  public WithPodSpecFluent.TemplateNested<A> withNewTemplateLike(PodSpecable item) {
    return new WithPodSpecFluentImpl.TemplateNestedImpl(item);
  }
  public WithPodSpecFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public WithPodSpecFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new PodSpecableBuilder().build());
  }
  public WithPodSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodSpecable item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WithPodSpecFluentImpl that = (WithPodSpecFluentImpl) o;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(template,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (template != null) { sb.append("template:"); sb.append(template); }
    sb.append("}");
    return sb.toString();
  }
  class TemplateNestedImpl<N> extends PodSpecableFluentImpl<WithPodSpecFluent.TemplateNested<N>> implements WithPodSpecFluent.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(PodSpecable item) {
      this.builder = new PodSpecableBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new PodSpecableBuilder(this);
    }
    PodSpecableBuilder builder;
    public N and() {
      return (N) WithPodSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/internal/knative/pkg/apis/duck/v1/WithPodSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WithPodSpecFluentImpl<A extends WithPodSpecFluent<A>> extends BaseFluent<A> implements WithPodSpecFluent<A>{
  public WithPodSpecFluentImpl() {
  }
  public WithPodSpecFluentImpl(WithPodSpec instance) {
    if (instance != null) {
      this.withTemplate(instance.getTemplate());
    }
  }
  private PodSpecableBuilder template;
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSpecable getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public PodSpecable buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(PodSpecable template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new PodSpecableBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public WithPodSpecFluentImpl.TemplateNested<A> withNewTemplate() {
    return new WithPodSpecFluentImpl.TemplateNestedImpl();
  }
  public WithPodSpecFluentImpl.TemplateNested<A> withNewTemplateLike(PodSpecable item) {
    return new WithPodSpecFluentImpl.TemplateNestedImpl(item);
  }
  public WithPodSpecFluentImpl.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public WithPodSpecFluentImpl.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new PodSpecableBuilder().build());
  }
  public WithPodSpecFluentImpl.TemplateNested<A> editOrNewTemplateLike(PodSpecable item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WithPodSpecFluentImpl that = (WithPodSpecFluentImpl) o;
    if (!java.util.Objects.equals(template, that.template)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(template,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (template != null) { sb.append("template:"); sb.append(template); }
    sb.append("}");
    return sb.toString();
  }
  class TemplateNestedImpl<N> extends PodSpecableFluentImpl<WithPodSpecFluentImpl.TemplateNested<N>> implements WithPodSpecFluentImpl.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(PodSpecable item) {
      this.builder = new PodSpecableBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new PodSpecableBuilder(this);
    }
    PodSpecableBuilder builder;
    public N and() {
      return (N) WithPodSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}
